aqequil API documentation

# Package `aqequil`

## Sub-modules

`aqequil.AqSpeciation`
`aqequil.MassTransfer`
`aqequil.check_TP_grid`

  check_TP_grid.py - Python conversion of check_TP_grid.r …

`aqequil.create_data0`

  Python implementation of create_data0.r Converts thermodynamic data into EQ3/6 data0 format

`aqequil.dissrxn_balancer`

  Module for checking and balancing dissociation reactions …

`aqequil.dissrxn_generator`

  Module for generating dissociation reactions for species that lack them …

`aqequil.fill_data0_header`
`aqequil.formula_parser`

  Shared utility functions for parsing chemical formulas and oxidation states …

`aqequil.output_3o_mine`

  3o_mine.py - Python conversion of 3o_mine.r …

`aqequil.preprocess_for_EQ3`

  preprocess_for_EQ3.py - Python conversion of preprocess_for_EQ3.r …

`aqequil.process_dissrxns`

  Main module for processing dissociation reactions in thermodynamic databases …

`aqequil.redox_suppression`

  Module for handling redox suppression in thermodynamic databases …